@@ -29,6 +29,7 @@ from filewrap import bio_chunk_iter, bio_chunk_async_iter, SupportsRead
 from http_response import (
     get_status_code, headers_get, decompress_response, parse_response, 
 )
+from socket_keepalive import socket_keepalive
 from yarl import URL
 
 from .. import normalize_request_args, SupportsGeturl
@@ -147,8 +148,10 @@ def urlopen(
     method: str = "GET", 
     data=None, 
     headers=None, 
-    **request_args, 
+    **request_kwargs, 
 ) -> HTTPResponse:
+    if headers is None:
+        headers = {}
     urlp = urlsplit(url)
     if urlp.scheme == "https":
         con: HTTPConnection = HTTPSConnection(urlp.netloc)
@@ -160,6 +163,7 @@ def urlopen(
         data, 
         headers, 
     )
+    socket_keepalive(con.sock)
     return con.getresponse()
 
 
